import {Component, OnInit} from "@angular/core";
import {BaseComponent} from "../../openaireLibrary/sharedComponents/base/base.component";
import {ActivatedRoute, Router} from "@angular/router";
import {PiwikService} from "../../openaireLibrary/utils/piwik/piwik.service";
import {Meta, Title} from "@angular/platform-browser";
import {SEOService} from "../../openaireLibrary/sharedComponents/SEO/SEO.service";

@Component({
  selector: 'methodological-approach',
  template: `
      <div class="uk-section" uk-scrollspy="target: [uk-scrollspy-class]; cls: uk-animation-fade; delay: 250">
          <div id="how" class="uk-container uk-container-large">
              <h1 class="uk-h2" uk-scrollspy-class>
                  Methodological <br>Approach<span
                      class="uk-text-primary">.</span>
              </h1>
              <div class="uk-width-large uk-text-large ">
                  The National Open Access Monitor for Ireland employs a robust methodology, underpinned by a commitment
                  to best practices in Open Science. This approach ensures comprehensive, accurate, and user-centric
                  insights into Ireland's Open Access landscape.
              </div>
          </div>
          <hr class="uk-margin-large-top uk-margin-large-bottom">
          <div class="uk-container uk-container-large">
              <h3 class="uk-h3 uk-text-center " uk-scrollspy-class>
                  Principles
              </h3>
              <div class="uk-margin-large-top uk-grid uk-child-width-1-2@m uk-child-width-1-1@s uk-grid-match" uk-grid>
                  <div class="uk-margin-small-bottom">
                      <div class="uk-card uk-card-default uk-card-body" uk-scrollspy-class>
                          <div class="uk-text-bold uk-margin-small-bottom">Openness & Transparency</div>
                          <div>We prioritize transparent methodological assumptions and the use of openly available,
                              public data.
                              Adherence to the FAIR principles and international standards ensures our findings are
                              trustworthy, replicable, and accessible for public engagement.
                          </div>
                      </div>
                  </div>
                  <div class="uk-margin-small-bottom">
                      <div class="uk-card uk-card-default uk-card-body" uk-scrollspy-class>
                          <div class="uk-text-bold uk-margin-small-bottom">Comprehensive Coverage & Accuracy</div>
                          <div>Leveraging the extensive data capabilities of the OpenAIRE Graph and working closely with
                              stakeholders for data representation and quality we aim to provide the most comprehensive
                              coverage possible, incorporating data from multiple sources for accurate and meaningful
                              indicators.
                          </div>
                      </div>
                  </div>
                  <div class="uk-margin-small-bottom">
                      <div class=" uk-card uk-card-default uk-card-body" uk-scrollspy-class>
                          <div class="uk-text-bold uk-margin-small-bottom">Readiness & Timeliness:</div>
                          <div>Built around well-established open databases and already tested knowledge extraction
                              technologies - natural language processing (NLP) / machine-learning (ML) - using
                              operational workflows in OpenAIRE to warrant timely results.
                          </div>

                      </div>
                  </div>
                  <div class="uk-margin-small-bottom">
                      <div class=" uk-card uk-card-default uk-card-body" uk-scrollspy-class>
                          <div class="uk-text-bold uk-margin-small-bottom">Engagement & Inclusivity</div>
                          <div>Our methodology focuses on meeting the needs of our diverse users, from researchers to
                              policymakers. We emphasize ease of use, clear communication, and responsiveness to
                              feedback. The platform is designed to be intuitive and responsive, ensuring an effective
                              and engaging experience for all stakeholders.
                          </div>

                      </div>
                  </div>
              </div>
          </div>
      </div>
      <div class="uk-banner uk-margin-large-top">
          <div class="uk-section uk-section-large uk-container uk-container-large">
              <div class="uk-grid uk-child-width-1-2@m" uk-grid>
                  <div>
                      <div style="max-width: 575px;">
                          <h2 class="uk-margin-small-top">DATA BACKBONE: THE OPENAIRE GRAPH<span
                                  class="text-graph">.</span></h2>
                          <div>
                              The National Open Access Monitor for Ireland is built upon the OpenAIRE Graph, a
                              comprehensive database of research metadata records. This extensive collection includes
                              records from 129K data sources, featuring around 3 million projects, 170 million
                              publications, 60 million datasets, 400K pieces of research software, and approximately 8
                              million other research outputs as of December 2023. Regular updates, conducted nearly
                              monthly, ensure the graph is consistently reflective of the latest scholarly
                              contributions.
                          </div>

                      </div>
                  </div>
                  <div class="uk-position-relative">
                      <img class=" uk-margin-medium-left uk-position-center-right uk-visible@m"
                           src="assets/common-assets/common/graph-nodes.svg" alt="OpenAIRE Graph" loading="lazy">
                  </div>
              </div>
          </div>
          <div class="uk-padding">
              <div class="uk-container uk-width-xlarge uk-margin-large-top">
                  At the core of the OpenAIRE Graph is a commitment to data quality. The pipeline processes metadata
                  from a multitude of sources, including detailed project information from funding bodies. Advanced
                  inference algorithms enhance the metadata and full texts of Open Access publications, establishing
                  crucial links between research results, projects, author affiliations, and classifications like Fields
                  of Science (FoS) and Sustainable Development Goals (SDGs). To maintain an open, trusted, and publicly
                  accessible resource, we apply sophisticated techniques for identifying and merging duplicate records,
                  supplemented by OpenAIRE's suite of curation tools, including the Metadata Validator for completeness
                  checks and OpenORGS for organization disambiguation.
              </div>
              <div class=" uk-margin-large-top uk-container uk-container-large">
                  <img class="uk-width-1-1"
                       src="assets/irish-assets/openaire-pipeline.png" alt="OpenAIRE pipeline" loading="lazy">
                  <div class="uk-text-meta uk-text-small uk-text-right uk-margin-top">Figure 1: Seemless Integration
                      with to OpenAIRE & EOSC
                  </div>
              </div>
              <div class="uk-container uk-width-xlarge uk-margin-large-top">
                  The OpenAIRE technology center is responsible with the upkeep of this robust infrastructure,
                  conducting regular hardware maintenance and implementing high-availability solutions, load balancing,
                  backups, and precise restore procedures to ensure uninterrupted system performance.
              </div>
              <div class="uk-container uk-width-xlarge uk-margin-top">
                  Explore the Graph in detail at the OpenAIRE Graph <a href="https://graph.openaire.eu" target="_blank">website</a>
                  and its <a href="https://graph.openaire.eu/docs/" target="_blank">documentation</a>.
              </div>
          </div>
      </div>
      <div class="uk-text-center uk-section uk-section-large">
          <div class="uk-text-large uk-text-primary"> Contact us</div>
          <div class="uk-h3 uk-margin-remove"> Your Feedback Matters</div>
          <div class="uk-flex uk-flex-center">
              <div class="uk-width-xlarge@m uk-width-1-1@s uk-margin-top uk-margin-medium-bottom"> If you notice any issues or have improvement
                  suggestions, please contact us. Your feedback is crucial for the continuous enhancement of our
                  platform and helps us maintain the highest accuracy and effectiveness.
              </div>
          </div>
          <a class="uk-button uk-button-primary" routerLink="/contact-us">contact us</a>
      </div>
  `
})
export class MethodologicalApproachComponent  extends BaseComponent implements OnInit {
  title = 'Methodological Approach';
  description = 'Methodological Approach';

  constructor(protected _route: ActivatedRoute,
              protected _piwikService: PiwikService,
              protected _meta: Meta,
              protected seoService: SEOService,
              protected _title: Title,
              protected _router: Router) {
    super();
  }

  ngOnInit() {
    this.setMetadata();
  }
}
